<template>
    <div class="device-info">
        <div class="header">
            <span class="title">告警级别分布</span>
        </div>

        <div
            ref="chartRef"
            style="width: 100%; min-height: calc(100% - 40px)"
        ></div>
    </div>
</template>
<script lang="ts" name="WarningLevel" setup>
import { useMenuStore } from '@/store/menu';
import * as echarts from 'echarts';
const chartRef = ref<Record<string, any>>({});
const menu = useMenuStore();
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            tooltip: {
                trigger: 'item',
            },
            legend: {
                orient: 'vertical',
                top: 'center',
                right: '10%',
            },
            series: [
                {
                    name: 'Access From',
                    type: 'pie',
                    left: '-20%',
                    radius: ['40%', '70%'],
                    avoidLabelOverlap: false,
                    label: {
                        show: false,
                        position: 'center',
                    },
                    emphasis: {
                        label: {
                            show: true,
                            fontSize: 40,
                            fontWeight: 'bold',
                        },
                    },
                    labelLine: {
                        show: false,
                    },
                    data: [
                        { value: 1048, name: 'Search Engine' },
                        { value: 735, name: 'Direct' },
                        { value: 580, name: 'Email' },
                        { value: 484, name: 'Union Ads' },
                        { value: 300, name: 'Video Ads' },
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

watch(
    () => menu.collapsed,
    (newX) => {
        setTimeout(() => {
            myChart.resize();
        }, 300);
    },
);

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
.device-info {
    flex: 2;
    height: 100%;
    background: white;
    .header {
        padding: 8px 16px;
        border-bottom: 1px dotted #e6e6e6;
        .title {
            font-size: 16px;
            font-family: PingFang SC-Medium, PingFang SC;
            font-weight: 500;
            color: #333333;
            line-height: 22px;
            border-left: 3px solid #4277ff;
            padding-left: 8px;
        }
    }
}
</style>
